#pragma once

#include "config.hpp"

namespace knx
{

class connection_private;

/**
 * \brief This class handles the ip connection(s) to the knx gateway
 */
class connection
{
public:
    /**
     * @brief creates the connection with given config
     */
    connection(const knx::config & config);

    //! @brief simple destructor
    ~connection();

    /**
     * @brief blocking start of the connection background thread
     *
     * This function is a blocking call to start the background thread.
     * It is normally only called by the handler.
     *
     * @warning you should not call this function from your code.
     */
    void start();

    /**
     * @brief non-blocking stop of the background thread
     *
     * This function send the termination signals and waits for the thread to stop.
     */
    void stop();

    /**
     * @brief central function to set any knx group value on the bus
     *
     * This function is used to set any value on the knx bus.
     */
    template<typename data_type>
    void set(std::string group, typename data_type::major_type::set_type data);

    /**
    * @brief central function to get any knx group value from the bus
    *
    * This function is used to get any value from the knx bus.
    *
    * @param group A valid group id as string (e.g. "1/2/3")
    * @return true if read was successful -- false otherwise
    */
    template<typename data_type>
    bool get(std::string group, typename data_type::major_type::set_type & data);

private:
    //! hidden implementation
    connection_private * connection_private_pointer;
    //! prevent copy
    connection(connection & rhs);
    //! prevent copy
    connection & operator=(connection & rhs);
};

}

