/**
 * @mainpage KNX interface library
 * @author Norbert Schmitz, knx@nagilo.de
 * @date July 2013
 * @version 1.0.0
 * @details
 *
 * This library can be used to access the home automation bus system KNX using an IP gateway.
 * More information on the bus may be found at www.knx.com .
 *
 * The whole program including the header files are free to be used in any non-commercial application.
 * A notification of usage to the author would be very nice.
 *
 * Commercial use is strictly forbidden. In case you are interested in a commercial license please contact the author.
 *
 * # Example
 *
 * A minimal code example would look like this when setting group 1/2/3 to on using a data point type of 1.001 .
 *
 * @code
 * #include "knx.hpp"
 * int main(int argc, char ** argv) {
 *   knx::config config(argc, argv);
 *   knx::connection connection(config);
 *   knx::handle handle(connection);
 *   connection.set<knx::dpt_switch>("1/2/3", knx::dpt_switch::ON);
 *   return 0;
 * }
 * @endcode
 *
 * # Features
 *
 * Although there are many eib/knx libraries available I started to develop an new knx library from scratch.
 * The reasons for this are the following:
 *
 * - Minimal dependencies:
 *
 *   Many existing libraries contain dependencies to additional libraries which make the compiltion process harder.
 *   libknx depends solely on boost. No other dependencies are allowed.
 *
 * - Platform independence:
 *
 *   libknx is portable.
 *   It is able to run on any linux operating system including Raspberry PI and on any Mac or Windows computer.
 *   The main development is realized on a Linux Debian 7.0 32bit machine but other distros and platforms will follow.
 *
 * - Reduce to the maximum:
 *
 *   The library on its own does not contain any additional overhead.
 *   It is capable of writing and reading knx messages -- nothing more and nothing less.
 *   Any additional ideas I or other may have should be based on libknx without extending the base system.
 *
 * # Current limitations
 *
 * libknx is a brand new development which means that many features are currently missing.
 * Most of them will be added in future.
 * Version 1.0.0 has the following limitations:
 *
 * - Only 3-part group addresses are available
 * - Only UDP communication is available
 * - Only data point types 1.001(rw), 5.001(r) amd 10.001(w) are available
 *
 * # Ideas
 *
 * The development of such a library directly creates tons of ideas what can be done with it.
 * Besides others these
 *
 * Yours
 * Norbert Schmitz
 */

/**
 * @file knx.hpp General include header for libknx.
 */

#include "config.hpp"

#include "connection.hpp"

#include "handle.hpp"

#include "dpt.hpp"

#include "data_point.hpp"



